@@ -1,7 +1,13 @@
 #' Get count of all edges or edges with distinct relationship types
-#' @description From a graph object of class \code{dgr_graph}, get a count of edges in the graph and optionally obtain a count of edges by their relationship type.
-#' @param graph a graph object of class \code{dgr_graph} that is created using \code{create_graph}.
-#' @param relationship either a logical value, where \code{TRUE} provides a named vector of edge count by type and \code{FALSE} (the default) provides a total count of edges, or, a string corresponding to one or more edge relationship types.
+#' @description From a graph object of class \code{dgr_graph}, get a count of
+#' edges in the graph and optionally obtain a count of edges by their
+#' relationship type.
+#' @param graph a graph object of class \code{dgr_graph} that is created using
+#' \code{create_graph}.
+#' @param rel either a logical value, where \code{TRUE} provides a
+#' named vector of edge count by type and \code{FALSE} (the default) provides
+#' a total count of edges, or, a string corresponding to one or more edge
+#' relationship types.
 #' @return a numeric vector of single length.
 #' @examples
 #' \dontrun{
@@ -18,7 +24,7 @@
 #'   create_edges(from = sample(LETTERS, replace = TRUE),
 #'                to = sample(LETTERS, replace = TRUE),
 #'                label = "edge",
-#'                relationship = "letter_to_letter")
+#'                rel = "letter_to_letter")
 #'
 #' graph <-
 #'   create_graph(nodes_df = nodes,
@@ -28,16 +34,16 @@
 #'                               "shape = circle"))
 #'
 #' # Get a total count of edges with no grouping
-#' edge_count(graph, relationship = FALSE)
+#' edge_count(graph, rel = FALSE)
 #' #> [1] 26
 #' }
 #' @export edge_count
 
 edge_count <- function(graph,
-                       relationship = FALSE){
+                       rel = FALSE){
 
   # If type is FALSE, get a total count of edges
-  if (relationship == FALSE){
+  if (rel == FALSE){
 
     if (is_graph_empty(graph) == TRUE){
 
@@ -53,7 +59,7 @@ edge_count <- function(graph,
   }
 
   # If relationship set to TRUE, get a named vector of counts by relationship
-  if (relationship == TRUE){
+  if (rel == TRUE){
 
     if (is_graph_empty(graph) == TRUE){
 
@@ -69,11 +75,12 @@ edge_count <- function(graph,
           all_relationships <- vector(mode = "character")
         }
 
-        all_relationships <- c(all_relationships,
-                               edge_relationship(graph = graph,
-                                                 from = all_edges[i,1],
-                                                 to = all_edges[i,2],
-                                                 action = "read"))
+        all_relationships <-
+          c(all_relationships,
+            edge_rel(graph = graph,
+                     from = all_edges[i,1],
+                     to = all_edges[i,2],
+                     action = "read"))
 
         all_relationships <- unique(all_relationships)
 
@@ -89,17 +96,19 @@ edge_count <- function(graph,
 
         total_edge_count <-
           c(total_edge_count,
-            nrow(graph$edges_df[which(graph$edges_df$relationship == all_relationships[i]),]))
+            nrow(graph$edges_df[which(graph$edges_df$rel ==
+                                        all_relationships[i]),]))
 
         if (i == length(all_relationships)){
           names(total_edge_count) <- all_relationships
 
           if (any(names(total_edge_count) == "")){
-            names(total_edge_count)[which(names(total_edge_count) == "")] <- "<no relationship>"
+            names(total_edge_count)[which(names(total_edge_count) == "")] <-
+              "<no rel>"
 
             total_edge_count <-
-              c(total_edge_count[which(names(total_edge_count) == "<no relationship>")],
-                total_edge_count[-which(names(total_edge_count) == "<no relationship>")])
+              c(total_edge_count[which(names(total_edge_count) == "<no rel>")],
+                total_edge_count[-which(names(total_edge_count) == "<no rel>")])
           }
         }
       }
@@ -109,7 +118,7 @@ edge_count <- function(graph,
   }
 
   # If relationship is a character vector, get counts by supplied relationships
-  if (class(relationship) == "character"){
+  if (class(rel) == "character"){
 
     if (is_graph_empty(graph) == TRUE){
 
@@ -126,11 +135,12 @@ edge_count <- function(graph,
           all_relationships <- vector(mode = "character")
         }
 
-        all_relationships <- c(all_relationships,
-                               edge_relationship(graph = graph,
-                                                 from = all_edges[i,1],
-                                                 to = all_edges[i,2],
-                                                 action = "read"))
+        all_relationships <-
+          c(all_relationships,
+            edge_rel(graph = graph,
+                     from = all_edges[i,1],
+                     to = all_edges[i,2],
+                     action = "read"))
 
         all_relationships <- unique(all_relationships)
 
@@ -142,47 +152,49 @@ edge_count <- function(graph,
 
       # Determine whether those edge relationships provides are all
       # available in the graph
-      relationships_are_available <- ifelse(all(relationship %in% all_relationships), TRUE, FALSE)
+      relationships_are_available <-
+        ifelse(all(rel %in% all_relationships), TRUE, FALSE)
 
       if (relationships_are_available){
 
         # Determine how many relationship rows are unsets for the edges
         # available in the graph
-        unset_relationship_for_node_count <- nrow(subset(graph$edges_df, relationship == ''))
+        unset_relationship_for_node_count <-
+          nrow(subset(graph$edges_df, rel == ''))
 
         # Determine the total count of edges with relationship not set
         # (if that was specified)
-        if (relationship == ""){
+        if (rel == ""){
 
           total_edge_count <- unset_relationship_for_node_count
         }
 
         # Determine the total count of edges with relationship set (if
         # that was specified)
-        if (relationship != ""){
+        if (rel != ""){
 
-          if (all(graph$edges_df$relationship == '') == FALSE){
+          if (all(graph$edges_df$rel == '') == FALSE){
 
             edges_df_set_relationship <- graph$edges_df
 
           } else {
 
             edges_df_set_relationship <-
-              graph$edges_df[-which(graph$edges_df$relationship == ''),]
+              graph$edges_df[-which(graph$edges_df$rel == ''),]
           }
 
-          for (i in 1:length(relationship)){
+          for (i in 1:length(rel)){
 
             if (i == 1) total_edge_count <- vector(mode = "numeric")
 
             total_edge_count <-
               c(total_edge_count,
-                nrow(edges_df_set_relationship[which(edges_df_set_relationship$relationship ==
-                                                       relationship[i]),]))
+                nrow(edges_df_set_relationship[which(edges_df_set_relationship$rel ==
+                                                       rel[i]),]))
 
-            if (i == length(relationship)){
+            if (i == length(rel)){
 
-              names(total_edge_count) <- relationship
+              names(total_edge_count) <- rel
             }
           }
         }
